public class Corso {
	/**
	 * Materia del corso.
	 */
	private String materia;

	/**
	 * Giorni in cui si svolge il corso.
	 */
	private Giorno[] giorni;

	/**
	 * Crea un nuovo corso.
	 * 
	 * @param materia
	 *            nome della materia.
	 * @param giorni
	 *            giorni di lezione.
	 */
	public Corso(String materia, Giorno... giorni) {
		this.materia = materia;
		this.giorni = giorni;
	}

	/**
	 * Restituisce la materia del corso.
	 * 
	 * @return materia del corso.
	 */
	public String getMateria() {
		return materia;
	}

	/**
	 * Restituisce il corso corrispondente a <code>this</code> posticipato di 
	 * <code>posticipo<code> giorni.
	 * 
	 * @param posticipo
	 *            numero di giorni di posticipo.
	 * @return Corso posticipato di <code>posticipo<code> giorni.
	 */
	public Corso getCorsoPosticipato(int posticipo) {
		Giorno[] giorniPosticipati = new Giorno[giorni.length];
		for (int i = 0; i < giorni.length; i++)
			giorniPosticipati[i] = giorni[i].seguente(posticipo);
		return new Corso(materia, giorniPosticipati);
	}

	@Override
	public final String toString() {
		String result = getMateria() + ": ";
		for (Giorno giorno: giorni)
			result += giorno + " ";

		return result + "\n";
	}
}
