/**
 * CLasse astratta che rappresenta una giorno della settimana
 * 
 * @author bioInfo
 *
 */
public abstract class Giorno {
	/**
	 * Campo privato che memorizza la posizione del giorno nella settimana.
	 */
	private int posizione;

	/**
	 * Costruisce un giorno che corrisponde alla posizione passata come parametro.
	 * 
	 * @param posizione
	 *            posizione del giorno nella settimana.
	 */
	protected Giorno(int posizione) {
		if (posizione < 0 || posizione >= 6)
			throw new Error("le posizioni vanno da 0 a 6");

		this.posizione = posizione;
	}

	/**
	 * Restituisce il giorno che segue <code>this</code> dopo il numero di giorni 
	 * passato come parametro
	 * 
	 * @param giorniTrascorsi
	 *            incremento da effettuare.
	 * @return il giorno che segue <code>this</code> dopo tanti giorni quanti sono 
	 *            indicati dal parametro <code>giorniTrascorsi</code>.
	 */
	public abstract Giorno seguente(int giorniTrascorsi);

	/**
	 * Restituisce la posizione nella settimana corrispondente a <code>this</code>.
	 * 
	 * @return la posizione del giorno.
	 */
	public int getPosizione() {
		return posizione;
	}

	@Override
	public abstract String toString();
}
